@@ -1,5 +1,7 @@
+import os
+
 # API version
-API_VERSION = "v1"
+API_VERSION = os.getenv("XAI_API_VERSION", "v1")
 
 # URIs of XAI base service starts here
 # Auth
@@ -8,6 +10,8 @@ LOGIN_URI = f"{API_VERSION}/access-token/authorize"
 # User
 GET_WORKSPACES_URI = f"{API_VERSION}/users/workspaces"
 CREATE_WORKSPACE_URI = f"{API_VERSION}/users/create_workspace"
+GET_NOTIFICATIONS_URI = f"{API_VERSION}/users/notifications"
+CLEAR_NOTIFICATIONS_URI = f"{API_VERSION}/users/clear-notifications"
 
 # Workspace
 UPDATE_WORKSPACE_URI = f"{API_VERSION}/users/workspace_config_update"
@@ -53,6 +57,18 @@ SEARCH_CASE_URI = f"{API_VERSION}/ai-models/search_case"
 CASE_INFO_URI = f"{API_VERSION}/ai-models/get_case_info"
 DELETE_CASE_URI = f"{API_VERSION}/project/delete_data_with_filter"
 
+# Observations
+GET_OBSERVATIONS_URI = f"{API_VERSION}/observations/get_observations"
+GET_OBSERVATION_PARAMS_URI = f"{API_VERSION}/observations/get_observation_params"
+CREATE_OBSERVATION_URI = f"{API_VERSION}/observations/create_observation"
+UPDATE_OBSERVATION_URI = f"{API_VERSION}/observations/observation_config_update"
+
+# Policies
+GET_POLICIES_URI = f"{API_VERSION}/policies/get_policies"
+GET_POLICY_PARAMS_URI = f"{API_VERSION}/policies/get_policy_params"
+CREATE_POLICY_URI = f"{API_VERSION}/policies/create_policy"
+UPDATE_POLICY_URI = f"{API_VERSION}/policies/policy_config_update"
+
 # Alerts
 GET_TRIGGERS_URI = f"{API_VERSION}/triggers/get_triggers"
 CREATE_TRIGGER_URI = f"{API_VERSION}/triggers/update_triggers"
