@@ -1,3 +1,4 @@
+from __future__ import annotations
 from pydantic import BaseModel
 from typing import List, Optional
 from aryaxai.client.client import APIClient
@@ -34,6 +35,9 @@ from aryaxai.common.xai_uris import (
     ALL_DATA_FILE_URI,
     AVAILABLE_TAGS_URI,
     CASE_INFO_URI,
+    CLEAR_NOTIFICATIONS_URI,
+    CREATE_OBSERVATION_URI,
+    CREATE_POLICY_URI,
     CREATE_TRIGGER_URI,
     DATA_DRFIT_DIAGNOSIS_URI,
     DELETE_CASE_URI,
@@ -48,6 +52,11 @@ from aryaxai.common.xai_uris import (
     GET_LABELS_URI,
     GET_MODEL_PERFORMANCE_URI,
     GET_MODELS_URI,
+    GET_NOTIFICATIONS_URI,
+    GET_OBSERVATION_PARAMS_URI,
+    GET_OBSERVATIONS_URI,
+    GET_POLICIES_URI,
+    GET_POLICY_PARAMS_URI,
     GET_PROJECT_CONFIG,
     MODEL_PARAMETERS_URI,
     MODEL_SUMMARY_URI,
@@ -57,6 +66,8 @@ from aryaxai.common.xai_uris import (
     TRAIN_MODEL_URI,
     UPDATE_ACTIVE_MODEL_URI,
     GET_TRIGGERS_URI,
+    UPDATE_OBSERVATION_URI,
+    UPDATE_POLICY_URI,
     UPDATE_PROJECT_URI,
     UPLOAD_DATA_FILE_INFO_URI,
     UPLOAD_DATA_FILE_URI,
@@ -75,6 +86,8 @@ from aryaxai.core.case import Case
 from aryaxai.core.model_summary import ModelSummary
 
 from aryaxai.core.dashboard import Dashboard
+from datetime import datetime
+import re
 
 
 class Project(BaseModel):
@@ -309,11 +322,11 @@ class Project(BaseModel):
         res = self.__api_client.post(DELETE_DATA_FILE_URI, payload)
         return res.get("details")
 
-    def upload_file(
-        self, file_path: str, tag: str, config: Optional[ProjectConfig] = None
+    def upload_data(
+        self, data: str | pd.DataFrame, tag: str, config: Optional[ProjectConfig] = None
     ) -> str:
-        """Uploads file for the current project
-        :param file_path: file path to be uploaded
+        """Uploads data for the current project
+        :param file_path: file path | dataframe to be uploaded
         :param config: project config
                 {
                     "project_type": "",
@@ -326,15 +339,29 @@ class Project(BaseModel):
         :return: response
         """
 
+        def build_upload_data():
+            if isinstance(data, str):
+                file = open(data, "rb")
+                return file
+            elif isinstance(data, pd.DataFrame):
+                csv_buffer = io.BytesIO()
+                data.to_csv(csv_buffer, index=False, encoding="utf-8")
+                csv_buffer.seek(0)
+                file_name = f"{tag}_sdk_{datetime.now().replace(microsecond=0)}.csv"
+                file = (file_name, csv_buffer.getvalue())
+                return file
+            else:
+                raise Exception("Invalid Data Type")
+
         def upload_file_and_return_path() -> str:
+            files = {"in_file": build_upload_data()}
             res = self.__api_client.file(
                 f"{UPLOAD_DATA_FILE_URI}?project_name={self.project_name}&data_type=data&tag={tag}",
-                file_path,
+                files,
             )
 
             if not res["success"]:
                 raise Exception(res.get("details"))
-
             uploaded_path = res.get("metadata").get("filepath")
 
             return uploaded_path
@@ -439,6 +466,56 @@ class Project(BaseModel):
 
         return res.get("details")
 
+    def upload_data_description(self, data: str | pd.DataFrame):
+        """uploads data description for the project
+
+        :param data: response
+        """
+
+        def build_upload_data():
+            if isinstance(data, str):
+                file = open(data, "rb")
+                return file
+            elif isinstance(data, pd.DataFrame):
+                csv_buffer = io.BytesIO()
+                data.to_csv(csv_buffer, index=False, encoding="utf-8")
+                csv_buffer.seek(0)
+                file_name = (
+                    f"data_description_sdk_{datetime.now().replace(microsecond=0)}.csv"
+                )
+                file = (file_name, csv_buffer.getvalue())
+                return file
+            else:
+                raise Exception("Invalid Data Type")
+
+        def upload_file_and_return_path() -> str:
+            files = {"in_file": build_upload_data()}
+            res = self.__api_client.file(
+                f"{UPLOAD_DATA_FILE_URI}?project_name={self.project_name}&data_type=data_description",
+                files,
+            )
+
+            if not res["success"]:
+                raise Exception(res.get("details"))
+            uploaded_path = res.get("metadata").get("filepath")
+
+            return uploaded_path
+
+        uploaded_path = upload_file_and_return_path()
+
+        payload = {
+            "path": uploaded_path,
+            "type": "data_description",
+            "project_name": self.project_name,
+        }
+        res = self.__api_client.post(UPLOAD_DATA_URI, payload)
+
+        if not res["success"]:
+            self.delete_file(uploaded_path)
+            raise Exception(res.get("details"))
+
+        return res.get("details", "Data description upload successful")
+
     def data_summary(self, tag: str) -> pd.DataFrame:
         """Data Summary for the project
 
@@ -462,9 +539,7 @@ class Project(BaseModel):
         }
 
         print(data)
-        summary = pd.DataFrame(res["data"]["data"][tag]).drop(
-            ["data_description"], axis=1
-        )
+        summary = pd.DataFrame(res["data"]["data"][tag])
         return summary
 
     def data_diagnosis(self, tag: str) -> pd.DataFrame:
@@ -1122,7 +1197,7 @@ class Project(BaseModel):
             return "No monitoring alerts found."
 
         return pd.DataFrame(monitoring_alerts)
-    
+
     def get_alert_details(self, id: str) -> dict:
         """get alert details by id
 
@@ -1138,27 +1213,23 @@ class Project(BaseModel):
         if not res["success"]:
             return Exception(res.get("details", "Failed to get trigger details"))
 
-        trigger_info =  res['details'][0]        
+        trigger_info = res["details"][0]
 
-        if not trigger_info['successful']:
-            return Alert(
-                info={},
-                detailed_report=[],
-                not_used_features=[]
-            )
+        if not trigger_info["successful"]:
+            return Alert(info={}, detailed_report=[], not_used_features=[])
+
+        trigger_info = trigger_info["details"]
+
+        detailed_report = trigger_info["detailed_report"]
+        not_used_features = trigger_info["Not_Used_Features"]
+
+        del trigger_info["detailed_report"]
+        del trigger_info["Not_Used_Features"]
 
-        trigger_info = trigger_info['details']
-        
-        detailed_report = trigger_info['detailed_report']
-        not_used_features = trigger_info['Not_Used_Features']
-        
-        del trigger_info['detailed_report']
-        del trigger_info['Not_Used_Features']
-        
         return Alert(
             info=trigger_info,
             detailed_report=detailed_report,
-            not_used_features=not_used_features
+            not_used_features=not_used_features,
         )
 
     def get_model_performance(self, model_name: str = None) -> Dashboard:
@@ -1185,7 +1256,14 @@ class Project(BaseModel):
         """Train new model
 
         :param model_type: type of model
-        :param data_config: config for the data, defaults to None
+        :param data_config: config for the data
+                        {
+                            "tags": List[str]
+                            "feature_exclude": List[str]
+                            "feature_encodings": List[str]
+                            "drop_duplicate_uid": bool
+                        },
+                        defaults to None
         :param model_config: config with hyper parameters for the model, defaults to None
         :return: response
         """
@@ -1461,7 +1539,7 @@ class Project(BaseModel):
         tag: Optional[str] = None,
         start_date: Optional[str] = None,
         end_date: Optional[str] = None,
-    ):
+    ) -> pd.DataFrame:
         """Cases for the Project
 
         :param unique_identifier: unique identifer of the case for filtering, defaults to None
@@ -1508,7 +1586,7 @@ class Project(BaseModel):
         unique_identifer: str,
         case_id: Optional[str] = None,
         tag: Optional[str] = None,
-    ):
+    ) -> Case:
         """Case Info
 
         :param unique_identifer: unique identifer of case
@@ -1537,7 +1615,15 @@ class Project(BaseModel):
         start_date: Optional[str] = None,
         end_date: Optional[str] = None,
         tag: Optional[str] = None,
-    ):
+    ) -> str:
+        """Delete Cases
+
+        :param unique_identifier: unique identifier of case, defaults to None
+        :param start_date: start date of case, defaults to None
+        :param end_date: end date of case, defaults to None
+        :param tag: tag of case, defaults to None
+        :return: response
+        """
         if tag:
             all_tags = self.all_tags()
             if tag not in all_tags:
@@ -1560,6 +1646,487 @@ class Project(BaseModel):
 
         return res["details"]
 
+    def get_notifications(self) -> pd.DataFrame:
+        """get user project notifications
+
+        :return: DataFrame
+        """
+        url = f"{GET_NOTIFICATIONS_URI}?project_name={self.project_name}"
+
+        res = self.__api_client.get(url)
+
+        if not res["success"]:
+            raise Exception("Error while getting project notifications.")
+
+        return pd.DataFrame(res["details"])
+
+    def clear_notifications(self) -> str:
+        """clear user project notifications
+
+        :raises Exception: _description_
+        :return: str
+        """
+        url = f"{CLEAR_NOTIFICATIONS_URI}?project_name={self.project_name}"
+
+        res = self.__api_client.post(url)
+
+        if not res["success"]:
+            raise Exception("Error while clearing project notifications.")
+
+        return res["details"]
+
+    def observations(self) -> pd.DataFrame:
+        """Observations
+
+        :return: observation details dataframe
+        """
+        res = self.__api_client.get(
+            f"{GET_OBSERVATIONS_URI}?project_name={self.project_name}"
+        )
+
+        if not res.get("details"):
+            raise Exception("No observations found")
+
+        observation_df = pd.DataFrame(res.get("details"))
+        observation_df = observation_df[
+            observation_df["status"].isin(["active", "inactive"])
+        ]
+        observation_df.reset_index(inplace=True, drop=True)
+        observation_df.insert(
+            10,
+            "expression",
+            observation_df["metadata"].apply(
+                lambda metadata: generate_expression(metadata["expression"])
+            ),
+        )
+        observation_df = observation_df.drop(
+            columns=[
+                "project_name",
+                "configuration",
+                "metadata",
+                "updated_by",
+                "created_by",
+                "updated_keys",
+            ]
+        )
+
+        return observation_df
+
+    def observation_trail(self) -> pd.DataFrame:
+        """Observation Trail
+
+        :return: observation trail details dataframe
+        """
+        res = self.__api_client.get(
+            f"{GET_OBSERVATIONS_URI}?project_name={self.project_name}"
+        )
+
+        if not res.get("details"):
+            raise Exception("No observations found")
+
+        observation_df = pd.DataFrame(res.get("details"))
+        observation_df = observation_df[
+            observation_df["status"].isin(["updated", "deleted"])
+        ]
+        observation_df.reset_index(inplace=True, drop=True)
+        observation_df = observation_df.rename(
+            columns={
+                "statement": "old_statement",
+                "linked_features": "old_linked_features",
+            }
+        )
+        observation_df["updated_keys"].replace(float("nan"), None, inplace=True)
+        observation_df.insert(
+            9,
+            "updated_statement",
+            observation_df["updated_keys"].apply(
+                lambda data: data.get("statement") if data else None
+            ),
+        )
+        observation_df.insert(
+            11,
+            "updated_linked_features",
+            observation_df["updated_keys"].apply(
+                lambda data: data.get("linked_features") if data else None
+            ),
+        )
+        observation_df.insert(
+            12,
+            "old_expression",
+            observation_df["metadata"].apply(
+                lambda metadata: generate_expression(metadata["expression"])
+            ),
+        )
+        observation_df.insert(
+            13,
+            "updated_expression",
+            observation_df["updated_keys"].apply(
+                lambda data: generate_expression(
+                    data.get("metadata", {}).get("expression")
+                )
+                if data
+                else None
+            ),
+        )
+
+        observation_df = observation_df.drop(
+            columns=[
+                "project_name",
+                "configuration",
+                "metadata",
+                "updated_by",
+                "created_by",
+                "updated_keys",
+            ]
+        )
+
+        return observation_df
+
+    def create_observation(
+        self,
+        observation_name: str,
+        expression: str,
+        statement: Optional[str] = None,
+        linked_features: Optional[List[str]] = None,
+    ) -> str:
+        """Creates New Observation
+
+        :param observation_name: name of observation
+        :param expression: expression of observation
+        :param statement: statement of observation, defaults to None
+        :param linked_features: linked features of observation, defaults to None
+        :return: response
+        """
+        configuration, expression = build_expression(expression)
+
+        observation_params = self.__api_client.get(
+            f"{GET_OBSERVATION_PARAMS_URI}?project_name={self.project_name}"
+        )
+
+        validate_configuration(configuration, observation_params["details"])
+
+        if linked_features:
+            for feature in linked_features:
+                if feature not in observation_params["eng_features"]:
+                    raise Exception(
+                        f"{feature} is not a valid feature, pick feature from \n{observation_params['eng_features']}"
+                    )
+
+        payload = {
+            "project_name": self.project_name,
+            "observation_name": observation_name,
+            "status": "active",
+            "configuration": configuration,
+            "metadata": {"expression": expression},
+            "statement": [statement],
+            "linked_features": linked_features,
+        }
+
+        res = self.__api_client.post(CREATE_OBSERVATION_URI, payload)
+        if not res["success"]:
+            raise Exception(res.get("details"))
+
+        return "Observation Created"
+
+    def update_observation(
+        self,
+        observation_id: str,
+        observation_name: str,
+        expression: Optional[str] = None,
+        statement: Optional[str] = None,
+        linked_features: Optional[List[str]] = None,
+    ) -> str:
+        """Updates Observation
+
+        :param observation_id: id of observation
+        :param observation_name: name of observation
+        :param expression: new expression for observaation, defaults to None
+        :param statement: new statement for observation, defaults to None
+        :param linked_features: new linked features for observation, defaults to None
+        :return: response
+        """
+        if not expression and not statement and not linked_features:
+            raise Exception("update parameters for observation not passed")
+
+        payload = {
+            "project_name": self.project_name,
+            "observation_id": observation_id,
+            "observation_name": observation_name,
+            "update_keys": {},
+        }
+
+        observation_params = self.__api_client.get(
+            f"{GET_OBSERVATION_PARAMS_URI}?project_name={self.project_name}"
+        )
+
+        if expression:
+            configuration, expression = build_expression(expression)
+            validate_configuration(configuration, observation_params["details"])
+            payload["update_keys"]["configuration"] = configuration
+            payload["update_keys"]["metadata"] = {"expression": expression}
+
+        if linked_features:
+            for feature in linked_features:
+                if feature not in observation_params["eng_features"]:
+                    raise Exception(
+                        f"{feature} is not a valid feature, pick feature from \n{observation_params['eng_features']}"
+                    )
+            payload["update_keys"]["linked_features"] = linked_features
+
+        if statement:
+            payload["update_keys"]["statement"] = [statement]
+
+        res = self.__api_client.post(UPDATE_OBSERVATION_URI, payload)
+
+        if not res["success"]:
+            raise Exception(res.get("details"))
+
+        return "Observation Updated"
+
+    def delete_observation(
+        self,
+        observation_id: str,
+        observation_name: str,
+    ) -> str:
+        """Deletes Observation
+
+        :param observation_id: id of observation
+        :param observation_name: name of observation
+        :return: response
+        """
+        payload = {
+            "project_name": self.project_name,
+            "observation_id": observation_id,
+            "observation_name": observation_name,
+            "delete": True,
+            "update_keys": {},
+        }
+
+        res = self.__api_client.post(UPDATE_OBSERVATION_URI, payload)
+
+        if not res["success"]:
+            raise Exception(res.get("details"))
+
+        return "Observation Deleted"
+
+    def policies(self) -> pd.DataFrame:
+        """Policies
+
+        :return: policy details dataframe
+        """
+        res = self.__api_client.get(
+            f"{GET_POLICIES_URI}?project_name={self.project_name}"
+        )
+
+        if not res.get("details"):
+            raise Exception("No policies found")
+
+        policy_df = pd.DataFrame(res.get("details"))
+        policy_df = policy_df[policy_df["status"].isin(["active", "inactive"])]
+        policy_df.reset_index(inplace=True, drop=True)
+        policy_df.insert(
+            11,
+            "expression",
+            policy_df["metadata"].apply(
+                lambda metadata: generate_expression(metadata["expression"])
+            ),
+        )
+        policy_df = policy_df.drop(
+            columns=[
+                "project_name",
+                "configuration",
+                "metadata",
+                "linked_features",
+                "updated_by",
+                "created_by",
+                "updated_keys",
+            ]
+        )
+        return policy_df
+
+    def policy_trail(self) -> pd.DataFrame:
+        """Policy Trail
+
+        :return: observation details dataframe
+        """
+        res = self.__api_client.get(
+            f"{GET_POLICIES_URI}?project_name={self.project_name}"
+        )
+
+        if not res.get("details"):
+            raise Exception("No policies found")
+
+        policy_df = pd.DataFrame(res.get("details"))
+        policy_df = policy_df[policy_df["status"].isin(["updated", "deleted"])]
+        policy_df.reset_index(inplace=True, drop=True)
+        policy_df = policy_df.rename(
+            columns={
+                "statement": "old_statement",
+                "decision": "old_decision",
+            }
+        )
+
+        policy_df["updated_keys"].replace(float("nan"), None, inplace=True)
+
+        policy_df.insert(
+            9,
+            "updated_statement",
+            policy_df["updated_keys"].apply(
+                lambda data: data.get("statement") if data else None
+            ),
+        )
+        policy_df.insert(
+            12,
+            "updated_decision",
+            policy_df["updated_keys"].apply(
+                lambda data: data.get("decision") if data else None
+            ),
+        )
+        policy_df.insert(
+            13,
+            "old_expression",
+            policy_df["metadata"].apply(
+                lambda metadata: generate_expression(metadata["expression"])
+            ),
+        )
+        policy_df.insert(
+            14,
+            "updated_expression",
+            policy_df["updated_keys"].apply(
+                lambda data: generate_expression(
+                    data.get("metadata", {}).get("expression")
+                )
+                if data
+                else None
+            ),
+        )
+
+        policy_df = policy_df.drop(
+            columns=[
+                "project_name",
+                "configuration",
+                "metadata",
+                "updated_by",
+                "created_by",
+                "updated_keys",
+                "linked_features",
+            ]
+        )
+
+        return policy_df
+
+    def create_policy(
+        self,
+        policy_name: str,
+        expression: str,
+        statement: Optional[str] = None,
+        decision: Optional[str] = None,
+    ) -> str:
+        """Creates New Policy
+
+        :param policy_name: name of policy
+        :param expression: expression of policy
+        :param statement: statement of policy, defaults to None
+        :param decision: decision of policy, defaults to None
+        :return: response
+        """
+        configuration, expression = build_expression(expression)
+
+        policy_params = self.__api_client.get(
+            f"{GET_POLICY_PARAMS_URI}?project_name={self.project_name}"
+        )
+
+        validate_configuration(configuration, policy_params["details"])
+
+        payload = {
+            "project_name": self.project_name,
+            "policy_name": policy_name,
+            "status": "active",
+            "configuration": configuration,
+            "metadata": {"expression": expression},
+            "statement": [statement],
+            "decision": decision,
+        }
+
+        res = self.__api_client.post(CREATE_POLICY_URI, payload)
+        if not res["success"]:
+            raise Exception(res.get("details"))
+
+        return "Policy Created"
+
+    def update_policy(
+        self,
+        policy_id: str,
+        policy_name: str,
+        expression: Optional[str] = None,
+        statement: Optional[str] = None,
+        decision: Optional[str] = None,
+    ) -> str:
+        """Updates Policy
+
+        :param policy_id: id of policy
+        :param policy_name: name of policy
+        :param expression: new expression for policy, defaults to None
+        :param statement: new statement for policy, defaults to None
+        :param decision: new decision for policy, defaults to None
+        :return: response
+        """
+        if not expression and not statement and not decision:
+            raise Exception("update parameters for policy not passed")
+
+        payload = {
+            "project_name": self.project_name,
+            "policy_id": policy_id,
+            "policy_name": policy_name,
+            "update_keys": {},
+        }
+
+        policy_params = self.__api_client.get(
+            f"{GET_POLICY_PARAMS_URI}?project_name={self.project_name}"
+        )
+
+        if expression:
+            configuration, expression = build_expression(expression)
+            validate_configuration(configuration, policy_params["details"])
+            payload["update_keys"]["configuration"] = configuration
+            payload["update_keys"]["metadata"] = {"expression": expression}
+
+        if statement:
+            payload["update_keys"]["statement"] = [statement]
+
+        res = self.__api_client.post(UPDATE_POLICY_URI, payload)
+
+        if not res["success"]:
+            raise Exception(res.get("details"))
+
+        return "Policy Updated"
+
+    def delete_policy(
+        self,
+        policy_id: str,
+        policy_name: str,
+    ) -> str:
+        """Deletes Policy
+
+        :param policy_id: id of policy
+        :param policy_name: name of policy
+        :return: response
+        """
+        payload = {
+            "project_name": self.project_name,
+            "policy_id": policy_id,
+            "policy_name": policy_name,
+            "delete": True,
+            "update_keys": {},
+        }
+
+        res = self.__api_client.post(UPDATE_POLICY_URI, payload)
+
+        if not res["success"]:
+            raise Exception(res.get("details"))
+
+        return "Policy Deleted"
+
     def __print__(self) -> str:
         return f"Project(user_project_name='{self.user_project_name}', created_by='{self.created_by}')"
 
@@ -1568,3 +2135,98 @@ class Project(BaseModel):
 
     def __repr__(self) -> str:
         return self.__print__()
+
+
+def generate_expression(expression):
+    if not expression:
+        return None
+    generated_expression = ""
+    for item in expression:
+        if isinstance(item, str):
+            generated_expression += " " + item
+        else:
+            generated_expression += (
+                f" {item['column']} {item['expression']} {item['value']}"
+            )
+    return generated_expression
+
+
+def build_expression(expression_string):
+    condition_operators = {
+        "!==": "_NOTEQ",
+        "==": "_ISEQ",
+        ">": "_GRT",
+        "<": "_LST",
+    }
+    logical_operator = {"and": "_AND", "or": "_OR"}
+
+    metadata_expression = []
+    configuration = []
+    pattern = re.compile(r"(\w+)\s*([!=<>]+)\s*(\w+)")
+    matches = pattern.findall(expression_string)
+    string_to_be_parsed = expression_string
+
+    for i, match in enumerate(matches):
+        column, expression, value = match
+        if expression not in condition_operators.keys():
+            raise Exception(f"Not a valid condition operator in {match}")
+        metadata_expression.append(
+            {
+                "column": column,
+                "value": value,
+                "expression": expression,
+            }
+        )
+        configuration.append(
+            {
+                "column": column,
+                "value": value,
+                "expression": condition_operators[expression],
+            }
+        )
+        if i < len(matches) - 1:
+            string_to_be_parsed = string_to_be_parsed.split(value, 1)[1]
+            operator = string_to_be_parsed.split(matches[i + 1][0], 1)[0]
+            operator_match = re.search(r"(|and|or|)", operator)
+            if not operator_match.group():
+                raise Exception(f"{operator} is not valid logical operator")
+            log_operator = operator_match.group()
+            if len(operator.split(log_operator)) > 1:
+                raise Exception(f"{operator} is not valid logical operator")
+            metadata_expression.append(log_operator)
+            configuration.append(logical_operator[log_operator])
+    return configuration, metadata_expression
+
+
+def validate_configuration(configuration, params):
+    for expression in configuration:
+        if isinstance(expression, str):
+            if expression not in params.get("logical_operators"):
+                raise Exception(f"{expression} not a valid logical operator")
+
+        if isinstance(expression, dict):
+            if expression.get("column") not in params.get("eng_features"):
+                raise Exception(
+                    f"{expression.get('column')} is not a valid feature, select valid features from\n{params.get('eng_features')}"
+                )
+            if expression.get("expression") not in params.get("condition_operators"):
+                raise Exception(
+                    f"{expression.get('expression')} is not a valid expression"
+                )
+            value_valid_values = params.get("features").get(expression.get("value"))
+            if isinstance(value_valid_values, str):
+                if (
+                    value_valid_values != "input"
+                    and expression.get("value") != value_valid_values
+                ):
+                    raise Exception(
+                        f"Invalid value comparision with {expression.get('value')} for {expression.get('column')}"
+                    )
+            if isinstance(value_valid_values, list):
+                if (
+                    "input" not in value_valid_values
+                    and expression.get("value") not in value_valid_values
+                ):
+                    raise Exception(
+                        f"Invalid value comparision with {expression.get('value')} for {expression.get('column')}"
+                    )
